#!/bin/bash

### GAD PIPELINE ###
## trim_fastq.sh
## Version : 2.4.0
## Description : This script allows user to launch Trimmomatic program
### Usage : qsub -pe smp 1 -v INPUTFILEONE=</path/to/the/R1/input/file>,INPUTFILETWO=</path/to/the/R2/input/file>,OUTPUTFILEONE=</path/to/the/R1/output/file>,OUTPUTFILETWO=</path/to/the/R2/output/file>,FASTQCFILEONE=</path/to/the/R1/fastqc/summary/file>,FASTQCFILETWO=</path/to/the/R2/fastqc/summary/file>,MISEQ=T|F,[LOGFILE=</path/to/the/log/file>],[CONFIGFILE=/path/to/the/config/file] trim_fastq.sh
## Output : Trimmed fastq file
## Requirements : Python 2.7, Trimmomatic

## Author : Emilie.Tisserant@u-bourgogne.fr
## Creation Date : 20160106
## last revision date : 20160112
## Known bugs : None

#$ -q batch
#$ -V

# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=trim_fastq.$(date +"%F_%H-%M-%S").log
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input files exist
if [ ! -f $INPUTFILEONE ] || [ ! -f $INPUTFILETWO ]
then
    echo "Input files do not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch trim_fastq.failed
    exit 1
fi

# Check if fastqc summary files exist
if [ ! -f $FASTQCFILEONE ] || [ ! -f $FASTQCFILETWO ]
then
    echo "Fastqc files do not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch trim_fastq.failed
    exit 1
fi

# Check if output files are specified
if [ -z $OUTPUTFILEONE ] || [ -z $OUTPUTFILETWO ]
then
    echo "Output files are not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch trim_fastq.failed
    exit 1
fi

# Check if miseq option is specified
if [ -z $MISEQ ]
then
    echo "Miseq option is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch trim_fastq.failed
    exit 1
fi

# Unpaired output file names
UNPAIREDFILEONE=${OUTPUTFILEONE%.*}.unpaired.gz
UNPAIREDFILETWO=${OUTPUTFILETWO%.*}.unpaired.gz

# configfile
JAVA=$(grep "javacmd" $CONFIGFILE | awk '{print $2" "$3}')
TRIMMOMATICBIN=$(grep "trimmomatic" $CONFIGFILE | awk '{print $2}')
ADAPTERS=$(grep "adapters_file" $CONFIGFILE | awk '{print $2}')

# Parse fastqc summary files
doQual=0
doAdapt=0
doFirstBase=0

RoneSeqQual=`grep "Per base sequence quality" $FASTQCFILEONE | cut -f1`
RtwoSeqQual=`grep "Per base sequence quality" $FASTQCFILETWO | cut -f1` 
RoneBaseCont=`grep "Per base sequence content" $FASTQCFILEONE | cut -f1`
RtwoBaseCont=`grep "Per base sequence content" $FASTQCFILETWO | cut -f1`
RoneKmerCont=`grep "Kmer Content" $FASTQCFILEONE | cut -f1`
RtwoKmerCont=`grep "Kmer Content" $FASTQCFILETWO | cut -f1`
RoneAdaptCont=`grep "Adapter Content" $FASTQCFILEONE | cut -f1`
RtwoAdaptCont=`grep "Adapter Content" $FASTQCFILETWO | cut -f1`

if [ -z $RoneSeqQual ] || [ -z $RtwoSeqQual ] || [ -z $RoneBaseCont ] || [ -z $RtwoBaseCont ] || [ -z $RoneKmerCont ] || [ -z $RtwoKmerCont ] || [ -z $RoneAdaptCont ] || [ -z $RtwoAdaptCont ]
then
    echo "Fastqc summary file parsing failed"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch trim_fastq.failed
    exit 1
fi

if [ "$RoneSeqQual" = "FAIL" ] || [ "$RtwoSeqQual" = "FAIL" ]
then 
    echo "Base quality failed fastqc test"
    doQual=1
fi 
if [ "$RoneBaseCont" = "FAIL" ] || [ "$RtwoBaseCont" = "FAIL" ]
then 
    echo "Base content failed fastqc test"
    doFirstBase=1
fi 
if [ "$RoneKmerCont" = "FAIL" ] || [ "$RtwoKmerCont" = "FAIL" ]
then 
    echo "Kmer content failed fastqc test"
    doAdapt=1
fi 
if [ "$RoneAdaptCont" = "FAIL" ] || [ "$RtwoAdaptCont" = "FAIL" ]
then 
    echo "Adapter content failed fastqc test"
    doAdapt=1
fi 

if [ "$doQual" -eq 1 ] || [ "$doAdapt" -eq 1 ] || [ "$doFirstBase" -eq 1 ]
then
    # Constructing options for trimming 
    echo "One or more fastqc tests failed : launching trimming on fastq files"
    TRIM_ADAPTERS=""
    CUT_FIRST=""
    TRIM_QUALITY=""
    LENGTH="MINLEN:40"
	if [ "$doAdapt" -eq "1" ] && [ "$MISEQ" == "F" ]
	then
	    TRIM_ADAPTERS="ILLUMINACLIP:$ADAPTERS:2:30:10:3:true"
	fi	
	if [ "$doFirstBase" -eq "1" ] && [ "$MISEQ" == "F" ]
	then
	    CUT_FIRST="HEADCROP:1"
	fi	
	if [ "$doQual" -eq "1" ]
	then 
	    TRIM_QUALITY="SLIDINGWINDOW:4:15"
	fi

    # Launch Trimmomatic and check exit code
    echo "Trimmomatic command: $JAVA -jar $TRIMMOMATICBIN PE -threads $NSLOTS $INPUTFILEONE $INPUTFILETWO $OUTPUTFILEONE $UNPAIREDFILEONE $OUTPUTFILETWO $UNPAIREDFILETWO $TRIM_ADAPTERS $CUT_FIRST $TRIM_QUALITY $LENGTH"
    $JAVA -jar $TRIMMOMATICBIN PE -threads $NSLOTS $INPUTFILEONE $INPUTFILETWO $OUTPUTFILEONE $UNPAIREDFILEONE $OUTPUTFILETWO $UNPAIREDFILETWO $TRIM_ADAPTERS $CUT_FIRST $TRIM_QUALITY $LENGTH
    trimmomatic_exitcode=$?
    echo "Trimmomatic exit code : $trimmomatic_exitcode"
    if [ $trimmomatic_exitcode != 0 ]
    then
        echo "$(date +"%F_%H-%M-%S"): END"
        touch trim_fastq.failed
        exit 1
    fi

    # Rename fastq fileq
    sampleName=${INPUTFILEONE%%.*}
    echo "Command : mv $sampleName.R1.fastq.gz $sampleName.R1.fastq.gz.orig.bak"
    mv $sampleName.R1.fastq.gz $sampleName.R1.fastq.gz.orig.bak
    echo "Command : mv $sampleName.R2.fastq.gz $sampleName.R2.fastq.gz.orig.bak"
    mv $sampleName.R2.fastq.gz $sampleName.R2.fastq.gz.orig.bak
    echo "Command : mv $sampleName.trimmed.R1.fastq.gz $sampleName.R1.fastq.gz"
    mv $sampleName.trimmed.R1.fastq.gz $sampleName.R1.fastq.gz
    echo "Command : mv $sampleName.trimmed.R2.fastq.gz $sampleName.R2.fastq.gz"
    mv $sampleName.trimmed.R2.fastq.gz $sampleName.R2.fastq.gz

    # Remove unpaired files
    echo "Command : rm $UNPAIREDFILEONE"
    rm $UNPAIREDFILEONE
    echo "Command : rm $UNPAIREDFILETWO"
    rm $UNPAIREDFILETWO

else
    echo "No fastqc test failed : No trimming on fastq files"
fi

echo "$(date +"%F_%H-%M-%S"): END"















