#!/bin/bash

### GAD PIPELINE ###
## wrapper_rMATS.sh
## Description : perform differential analysis of outlier rare splice from rMATS analysis
##                B1 & B2 files are containing BAM file path to the 2 groups for the analysis
##                They will be generated in the script, but need to be named
## Usage : qsub -v DESIGN=<design_file>,B1=<path_to_b1_file>,B2=<path_to_b2_file>,INPUTDIR=<path_to_the_output_directory>,OUTPUTDIR=<path_to_the_output_directory>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_rMATS.sh
## Output :
## Requirements : rMATS

## Author : emilie.tisserant@u-bourgogne.fr, yannis.duffourd@u-bourgogne.fr
## Creation Date : 20180420
## last revision date : 20201006
## Known bugs : None


#$ -V
#$ -q batch



# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=rmats.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input file exist
if [ ! -f $DESIGN ]
then
    echo "Design file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch rMATS.failed
    exit 1
fi

# Check outputdir
if [ -z ${OUTPUTDIR} ]
then
  echo "Output directory not specified"
  echo "$(date +"%F_%H-%M-%S"): END"
  touch rMATS.failed
  exit 1
fi

# Check inputdir
if [ -z ${INPUTDIR} ]
then
  echo "Input directory not specified"
  echo "$(date +"%F_%H-%M-%S"): END"
  touch rMATS.failed
  exit 1
fi

# Check B1
if [ -z ${B1} ]
then
  echo "B1 not specified"
  echo "$(date +"%F_%H-%M-%S"): END"
  touch rMATS.failed
  exit 1
fi

# Check B2
if [ -z ${B2} ]
then
  echo "B2 not specified"
  echo "$(date +"%F_%H-%M-%S"): END"
  touch rMATS.failed
  exit 1
fi


export LD_LIBRARY_PATH=/work/gad/shared/bin/gsl/gsl-2.6/.libs:/work/gad/shared/bin/gsl/gsl-2.6/cblas/.libs:$LD_LIBRARY_PATH
PIPELINEBASE=`grep pipelinebase $CONFIGFILE | cut -f2`
PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
RMATSBIN=$(grep "rmatsbin" $CONFIGFILE | awk '{print $2}')
HG19GTF=$(grep "hg19gtf" $CONFIGFILE | awk '{print $2}')


# create list of bam files from design
sample=`basename ${DESIGN%%.*}`

if [ -f "$B1" ]
then
  rm $B1
fi
if [ -f "$B2" ]
then
  rm $B2
fi


while read line
do
  # reading each line
  status=$(echo $line | cut -d " " -f2)
  name=$(echo $line | cut -d " " -f1)
  if [ "$status" = "sample" ]
  then
    echo "$name is a $status : in $B1"
    echo -n "$INPUTDIR/$name/$name.sort.bam," >> $B1
  else
    echo "$name is a $status : in $B2"
    echo -n "$INPUTDIR/$name/$name.sort.bam," >> $B2
  fi
  echo $status
done < $DESIGN



echo "Command : $PYTHONBIN $RMATSBIN --b1 $B1 --b2 $B2 --gtf $HG19GTF --od $OUTPUTDIR -t paired --readLength 150 --libType fr-secondstrand --nthread $NSLOTS --cstat 0.05"
$PYTHONBIN $RMATSBIN --b1 $B1 --b2 $B2 --gtf $HG19GTF --od $OUTPUTDIR -t paired --readLength 150 --libType fr-secondstrand --nthread $NSLOTS --cstat 0.05

rmats_exit_code=$?
echo "wrapper_rMATS.sh exit code : $rmats_exit_code"
if [ $rmats_exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch rMATS.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
